#!/usr/bin/env python3

from .version import __version__

from .figure import Figure
from .colormap import *
from .utils import *

from .utils import fonts
fonts.main()
